<?php
/*
Plugin Name: Origin Layouts Manager
Description: Enables saving and managing custom SiteOrigin Page Builder layouts in WordPress Admin, creating reusable templates for pages and posts.
Version: 1.0
Requires at least: 5.8
Tested up to: 6.7
Requires PHP: 7.4
License: GPL-2.0+
License URI: https://www.gnu.org/licenses/gpl-2.0.html
Author: Kodeala
Author URI: https://www.kodeala.com
Text Domain: origin-layouts-manager
Tags: siteorigin, layout, templates, save, page builder  
*/

if ( ! defined( 'ABSPATH' ) ) {
    exit; // Exit if accessed directly.
}

//Add Plugin CSS and JS to Admin
function kodeala_olm_style_script_loader() {
    wp_register_style('kodeala_olm_admin_css', plugins_url('css/styles.css', __FILE__), false, '1.0.0');
        wp_enqueue_style('kodeala_olm_admin_css');

        wp_register_script('kodeala_olm_admin_js', plugins_url('js/functions.js', __FILE__), array('jquery'), '1.0.0', true);
        wp_enqueue_script('kodeala_olm_admin_js');

        // Localize the script with new data
        wp_localize_script('kodeala_olm_admin_js', 'kodealaAjax', array(
            'ajax_url' => admin_url('admin-ajax.php'),
            'nonce'    => wp_create_nonce('kodeala_olm_nonce'),
        ));
}
add_action('admin_enqueue_scripts', 'kodeala_olm_style_script_loader');


//If olm-template is not enabled on SiteOrigin settings, Enable it.
function kodeala_update_siteorigin_settings($kodeala_template_posttype) {
    // Retrieve the existing SiteOrigin Panels settings
    $kodeala_siteorigin_settings = 'siteorigin_panels_settings';
    $kodeala_siteorigin_option = get_option($kodeala_siteorigin_settings);

    // Check if the 'post-types' option exists and is an array
    if (!isset($kodeala_siteorigin_option['post-types']) || !is_array($kodeala_siteorigin_option['post-types'])) {
        $kodeala_siteorigin_option['post-types'] = array(); // Initialize if not set
    }

    // Get the current post types
    $post_type_options = $kodeala_siteorigin_option['post-types'];

    // Ensure the 'kodealaolm-templates' post type is enabled
    if (!in_array($kodeala_template_posttype, $post_type_options, true)) {
        $post_type_options[] = $kodeala_template_posttype; // Add the post type

        // Update the settings with the modified post types array
        $kodeala_siteorigin_option['post-types'] = $post_type_options;

        // Use update_option to save the changes
        update_option($kodeala_siteorigin_settings, $kodeala_siteorigin_option);
    }
}

// Call the function with your post type
kodeala_update_siteorigin_settings('kodealaolm-templates');

//Set JSON data loop for template layouts
function kodeala_olm_template_layouts($layouts) {
    $args = array(
        'post_type' => 'kodealaolm-templates',
        'post_status' => 'publish',
        'posts_per_page' => -1,
        'orderby' => 'title',
        'order' => 'ASC',
    );

    $templateloop = new WP_Query($args);

    while ($templateloop->have_posts()) : $templateloop->the_post();
        $templatepostID = get_the_ID();
        $templatepostThumb = get_the_post_thumbnail_url($templatepostID);
        $templateDescription = get_post_meta($templatepostID, 'kodeala_olm_description', true);
    
        if (!$templatepostThumb) {
            $templatepostThumb = plugins_url('origin-layouts-manager/images/templates-placeholder.png', dirname(__FILE__));
        }

        // Ensure post thumbnail URL is properly escaped
        $templatepostThumb = esc_url($templatepostThumb);

        $panel_template_data = get_post_meta($templatepostID, 'panels_data', true);
        if (!is_array($panel_template_data)) {
            $panel_template_data = json_decode($panel_template_data, true);
            if (json_last_error() !== JSON_ERROR_NONE) {
                $panel_template_data = array(); // Handle JSON errors gracefully
            }
        }
    
        $layouts[$templatepostID . '-' . sanitize_title(get_the_title())] = wp_parse_args(
            array(
                'name' => sanitize_text_field(get_the_title()),
                'description' => sanitize_text_field($templateDescription),
                'screenshot' => $templatepostThumb,
            ),
            $panel_template_data
        );
    endwhile;

    wp_reset_postdata();
    return $layouts;
}
add_filter('siteorigin_panels_prebuilt_layouts', 'kodeala_olm_template_layouts');

include_once dirname(__FILE__).'/inc/kodealaolm-cpt.php';
include_once dirname(__FILE__).'/inc/kodealaolm-ajax.php';
?>