<?php
if ( ! defined( 'ABSPATH' ) ) {
    exit; // Exit if accessed directly.
}

function kodeala_escape_json($json) {
    return preg_replace_callback('/(<[^>]+>)/', function ($matches) {
        return addslashes($matches[0]);
    }, $json);
}
function kodeala_savelayout_submitted() {
    // Verify nonce to ensure request authenticity
    check_ajax_referer('kodeala_olm_nonce', 'security');

    // Capability check to ensure the user has permissions to create posts
    if (!current_user_can('edit_posts')) {
        wp_send_json_error('Permission denied');
        wp_die();
    }

    // Get Data from POST with sanitization
    $panel_action   = sanitize_text_field(wp_unslash($_POST['panel_action'] ?? ''));
    $raw_panel_json = isset($_POST['panel_json']) ? wp_kses_post(wp_unslash($_POST['panel_json'])) : null;
    $panel_json     = $raw_panel_json ? (json_last_error() === JSON_ERROR_NONE ? json_decode(kodeala_escape_json($raw_panel_json), true) : null) : null;
    $panel_data     = isset($_POST['panel_content']) ? wp_kses_post(wp_unslash($_POST['panel_content'])) : '';
    $post_id        = intval($_POST['post_id'] ?? 0);
    $post_title     = isset($_POST['post_title']) ? sanitize_text_field(wp_unslash($_POST['post_title'])) : '';
    $template_title = isset($_POST['template_title']) ? sanitize_text_field(wp_unslash($_POST['template_title'])) : '';
    $current_date   = current_time('F j, Y, h:i:sa'); // Localized current date/time

    // Validate post ID
    if ($post_id > 0 && !get_post($post_id)) {
        wp_send_json_error('Invalid post ID');
        wp_die();
    }

    // Whitelist check for panel action
    $allowed_actions = ['kodeala_savelayout_fired'];
    if (!in_array($panel_action, $allowed_actions, true)) {
        wp_send_json_error('Invalid panel action');
        wp_die();
    }

    // Decode HTML entities if necessary
    $panel_data_decode = htmlspecialchars_decode($panel_data, ENT_QUOTES);

    // Sanitize JSON content
    function sanitize_json_content($data) {
        if (is_array($data)) {
            foreach ($data as $key => $value) {
                $data[$key] = sanitize_json_content($value);
            }
        } elseif (is_string($data)) {
            $data = wp_kses_post($data);
        }
        return $data;
    }

    if (json_last_error() === JSON_ERROR_NONE) {
        $sanitized_data = sanitize_json_content($panel_data_decode);
        $panel_data_decode = wp_json_encode($sanitized_data);
        if ($panel_data_decode === false) {
            wp_send_json_error('Error encoding JSON');
            wp_die();
        }
    } else {
        $panel_data_decode = '';
    }

    // Sanitize and validate panel_json
    if (is_array($panel_json)) {
        $panel_json = sanitize_json_content($panel_json);
    } else {
        wp_send_json_error('Invalid panel JSON data');
        wp_die();
    }

    // Verify expected action is present
    if ($panel_action === 'kodeala_savelayout_fired') {
        $olmtemplate_posttype = 'kodealaolm-templates';

        // Prepare the post data array securely
        $olmtemplate_post = array(
            'post_content' => $panel_data_decode,
            'post_status'  => 'publish',
            'post_author'  => get_current_user_id(),
            'post_type'    => $olmtemplate_posttype
        );

        // Determine post title with fallback to current date
        $olmtemplate_post['post_title'] = $template_title ?: ($post_title ?: $current_date);

        // Check if a post with the same title already exists and append date if necessary
        $args = array(
            'post_type'      => $olmtemplate_posttype,
            'posts_per_page' => 1,
            's'              => $olmtemplate_post['post_title'],
            'post_status'    => 'any',
        );
        $query = new WP_Query($args);

        // Check if the post exists
        if ($query->have_posts()) {
            $olmtemplate_exists = $query->posts[0];
        } else {
            $olmtemplate_exists = null;
        }
        if ($olmtemplate_exists) {
            $olmtemplate_post['post_title'] .= ' - ' . $current_date;
        }

        // Insert the post and check for success
        $insertTemplate = wp_insert_post($olmtemplate_post);
        if (is_wp_error($insertTemplate)) {
            wp_send_json_error('Failed to create template');
            wp_die();
        }

        // Add post meta data securely
        add_post_meta($insertTemplate, 'panels_data', $panel_json, true);

        // Return success response
        wp_send_json_success('Template saved successfully');
    } else {
        wp_send_json_error('Invalid panel action');
    }

    wp_die();
}
add_action('wp_ajax_kodeala_savelayout_submitted', 'kodeala_savelayout_submitted');
?>