<?php
if ( ! defined( 'ABSPATH' ) ) {
    exit; // Exit if accessed directly.
}

function kodeala_olm_custom_post_type() {
    // Labels for the custom post type
    $labels = array(
        'name'                  => _x( 'Origin Templates', 'Post Type General Name', 'origin-layouts-manager' ),
        'singular_name'         => _x( 'Origin Template', 'Post Type Singular Name', 'origin-layouts-manager' ),
        'menu_name'             => __( 'Origin Templates', 'origin-layouts-manager' ),
        'all_items'             => __( 'Origin Templates', 'origin-layouts-manager' ),
        'view_item'             => __( 'View Template', 'origin-layouts-manager' ),
        'add_new_item'          => __( 'Add New Template', 'origin-layouts-manager' ),
        'add_new'               => __( 'Add New', 'origin-layouts-manager' ),
        'edit_item'             => __( 'Edit Template', 'origin-layouts-manager' ),
        'update_item'           => __( 'Update Template', 'origin-layouts-manager' ),
        'search_items'          => __( 'Search Template', 'origin-layouts-manager' ),
        'not_found'             => __( 'Not Found', 'origin-layouts-manager' ),
        'not_found_in_trash'    => __( 'Not found in Trash', 'origin-layouts-manager' ),
    );

    // Arguments for the custom post type
    $args = array(
        'label'                 => __( 'Origin Templates', 'origin-layouts-manager' ),
        'description'           => __( 'Templates for Site Origin Page Builder', 'origin-layouts-manager' ),
        'labels'                => $labels,
        'supports'              => array( 'title', 'editor', 'thumbnail' ),
        'public'                => false,
        'show_ui'               => true,
        'show_in_menu'          => 'tools.php',
        'menu_position'         => 50,
        'show_in_admin_bar'     => false,
        'show_in_nav_menus'     => false,
        'can_export'            => true,
        'has_archive'           => false,
        'exclude_from_search'   => false,
        'publicly_queryable'    => false,
        'capability_type'       => 'post',
        'rewrite'               => array(
            'slug' => 'kodealaolm-templates',
            'with_front' => false
        ),
        'show_in_rest'          => false,
    );

    // Register the custom post type
    register_post_type( 'kodealaolm-templates', $args );
}
add_action( 'init', 'kodeala_olm_custom_post_type' );

function kodeala_olm_add_custom_field_metabox() {
    add_meta_box(
        'kodeala_olm_description',
        'Layout Description',
        'kodeala_olm_render_description_metabox',
        'kodealaolm-templates',
        'normal',
        'default'
    );
}
add_action('add_meta_boxes', 'kodeala_olm_add_custom_field_metabox');

function kodeala_olm_render_description_metabox($post) {
    // Retrieve existing value from the database
    $description = get_post_meta($post->ID, 'kodeala_olm_description', true);

    // Output nonce for verification
    wp_nonce_field('kodeala_olm_save_description', 'kodeala_olm_description_nonce');

    // Output textarea
    ?>
    <textarea id="kodeala_olm_description" name="kodeala_olm_description" rows="5" style="width:100%;"><?php echo esc_textarea($description); ?></textarea>
    <?php
}

function kodeala_olm_save_description_metabox($post_id) {
    // Verify nonce
    if ( ! isset( $_POST['kodeala_olm_description_nonce'] ) || 
        !wp_verify_nonce( sanitize_text_field( wp_unslash( $_POST['kodeala_olm_description_nonce'] ) ), 'kodeala_olm_save_description' ) ) {
        return $post_id;
    }

    // Check for autosave
    if (defined('DOING_AUTOSAVE') && DOING_AUTOSAVE) {
        return $post_id;
    }

    // Check permissions
    if (!current_user_can('edit_post', $post_id)) {
        return $post_id;
    }

    // Save data
    if ( isset( $_POST['kodeala_olm_description'] ) ) {
        $description = sanitize_textarea_field( wp_unslash( $_POST['kodeala_olm_description'] ) );
        update_post_meta( $post_id, 'kodeala_olm_description', $description );
    }

    return $post_id;
}
add_action('save_post', 'kodeala_olm_save_description_metabox');

?>